@@ -13,6 +13,7 @@ from django.db.models import signals
 from django.utils import six
 from django.utils.http import urlquote
 from django.utils.translation import get_language
+from django.utils.encoding import python_2_unicode_compatible
 from django.template import Context
 from django.template.defaulttags import url as url_tag
 
@@ -106,13 +107,13 @@ def register_i18n_trees(aliases):
     _I18N_TREES = aliases
 
 
-def register_dynamic_trees(trees):
+def register_dynamic_trees(trees, *args):
     """Registers dynamic trees to be available for `sitetree` runtime.
     Expects `trees` to be an iterable with structures created with `compose_dynamic_tree()`.
 
     Example::
 
-        register_dynamic_trees((
+        register_dynamic_trees(
 
             # Get all the trees from `my_app`.
             compose_dynamic_tree('my_app'),
@@ -132,7 +133,7 @@ def register_dynamic_trees(trees):
                     item('dynamic_2', 'dynamic_2_url'),
                 )),
             )),
-        ))
+        )
 
     """
 
@@ -141,6 +142,10 @@ def register_dynamic_trees(trees):
     if _IDX_ORPHAN_TREES not in _DYNAMIC_TREES:
         _DYNAMIC_TREES[_IDX_ORPHAN_TREES] = {}
 
+    if isinstance(trees, dict):  # New `less-brackets` style registration.
+        trees = [trees]
+        trees.extend(args)
+
     for tree in trees:
         if tree is not None and tree['sitetrees'] is not None:
             if tree['tree'] is None:
@@ -200,6 +205,7 @@ def compose_dynamic_tree(src, target_tree_alias=None, parent_tree_item_alias=Non
     return None
 
 
+@python_2_unicode_compatible
 class LazyTitle(object):
     """Lazily resolves any variable found in a title of an item.
     Produces resolved title as unicode representation."""
@@ -207,7 +213,7 @@ class LazyTitle(object):
     def __init__(self, title):
         self.title = title
 
-    def __unicode__(self):
+    def __str__(self):
         my_lexer = template.Lexer(self.title, template.UNKNOWN_SOURCE)
         my_tokens = my_lexer.tokenize()
 
@@ -220,7 +226,7 @@ class LazyTitle(object):
         return my_parser.parse().render(SiteTree.get_global_context())
 
     def __eq__(self, other):
-        return self.__unicode__() == other
+        return self.__str__() == other
 
 
 class SiteTree(object):
@@ -274,7 +280,7 @@ class SiteTree(object):
         Almost all variables are resolved against global context.
 
         """
-        if not cls._global_context or hash(context) != hash(cls._global_context):
+        if not cls._global_context or id(context) != id(cls._global_context):
             cls._global_context = context
 
     @classmethod
@@ -434,7 +440,8 @@ class SiteTree(object):
         current_item = None
 
         if 'request' not in self._global_context:
-            raise SiteTreeError('Sitetree needs "django.core.context_processors.request" to be in TEMPLATE_CONTEXT_PROCESSORS in your settings file. If it is, check that your view pushes request data into the template.')
+            if settings.DEBUG:
+                raise SiteTreeError('Sitetree needs "django.core.context_processors.request" to be in TEMPLATE_CONTEXT_PROCESSORS in your settings file. If it is, check that your view pushes request data into the template.')
         else:
             # urlquote is an attempt to support non-ascii in url.
             current_url = urlquote(self._global_context['request'].path)
@@ -586,7 +593,7 @@ class SiteTree(object):
             elif branch_id == ALIAS_THIS_ANCESTOR_CHILDREN and current_item is not None:
                 branch_id = self.get_ancestor_item(tree_alias, current_item).id
                 parent_ids.append(branch_id)
-            elif branch_id == ALIAS_THIS_SIBLINGS and current_item is not None:
+            elif branch_id == ALIAS_THIS_SIBLINGS and current_item is not None and current_item.parent is not None:
                 branch_id = current_item.parent.id
                 parent_ids.append(branch_id)
             elif branch_id == ALIAS_THIS_PARENT_SIBLINGS and current_item is not None:
